"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.ajaxData = ajaxData;
exports.submitOCR = submitOCR;
exports.queryOCR = queryOCR;
exports.queryIdentity = queryIdentity;
exports.checkidentity = checkidentity;
exports.submitIdentity = submitIdentity;

require("vant/es/dialog/style");

var _dialog = _interopRequireDefault(require("vant/es/dialog"));

var _ajax = _interopRequireDefault(require("../../common/ajax"));

var API_BASE = '//h5.youzan.com/wscassets/api/payment/account';
/**
 * 封装ajax请求
 * @param {Object} options 请求参数
 * @return {Promise}
 */

function ajaxData(options) {
  return (0, _ajax.default)(options).then(function (resp) {
    // 互斥登录提示
    if (resp.code === 109) {
      return _dialog.default.alert({
        message: resp.msg
      }).then(function () {
        return window.location.href = "https://passport.youzan.com/login?redirectUrl=" + encodeURIComponent(window.location.href);
      });
    }

    if (resp.code !== 0) {
      return Promise.reject(resp.msg);
    }

    return Promise.resolve(resp.data);
  }).catch(function (error) {
    if (typeof error === 'string') return Promise.reject(error);
    return Promise.reject(error.message || error.msg || '系统错误');
  });
}
/**
 * 提交OCR识别
 * doc: https://doc.qima-inc.com/pages/viewpage.action?pageId=176850664#id-%E3%80%90%E6%8E%A5%E5%8F%A3%E6%96%87%E6%A1%A3%E3%80%91%E4%B8%AA%E4%BA%BA%E4%BC%9A%E5%91%98%E5%BC%80%E6%88%B7%E5%8F%8A%E6%94%AF%E4%BB%98%E5%AF%86%E7%A0%81%E8%83%BD%E5%8A%9B%E5%BB%BA%E8%AE%BE-1.%E6%8F%90%E4%BA%A4ocr
 * @param {Object} params 请求参数
 * @return {Promise}
 */


function submitOCR(params) {
  return ajaxData({
    url: API_BASE + "/activation/verification/ocr/submit",
    method: 'POST',
    contentType: 'application/json',
    data: params
  });
}
/**
 * @description 查询OCR识别
 * @export
 * @param {*} data
 * @return {Promise}
 */


function queryOCR(data) {
  return ajaxData({
    url: API_BASE + "/activation/verification/ocr/query",
    data: data
  });
}
/**
 * 查询用户身份信息
 * doc: https://doc.qima-inc.com/pages/viewpage.action?pageId=176850664#id-%E3%80%90%E6%8E%A5%E5%8F%A3%E6%96%87%E6%A1%A3%E3%80%91%E4%B8%AA%E4%BA%BA%E4%BC%9A%E5%91%98%E5%BC%80%E6%88%B7%E5%8F%8A%E6%94%AF%E4%BB%98%E5%AF%86%E7%A0%81%E8%83%BD%E5%8A%9B%E5%BB%BA%E8%AE%BE-5.%E6%9F%A5%E8%AF%A2%E7%94%A8%E6%88%B7%E7%9A%84%E8%BA%AB%E4%BB%BD%E4%BF%A1%E6%81%AF
 * @return {Promise}
 */


function queryIdentity() {
  return ajaxData({
    url: API_BASE + "/activation/verification/identity/query",
    method: 'GET'
  });
}
/**
 * 校验用户身份信息
 * doc: https://doc.qima-inc.com/pages/viewpage.action?pageId=176850664#id-%E3%80%90%E6%8E%A5%E5%8F%A3%E6%96%87%E6%A1%A3%E3%80%91%E4%B8%AA%E4%BA%BA%E4%BC%9A%E5%91%98%E5%BC%80%E6%88%B7%E5%8F%8A%E6%94%AF%E4%BB%98%E5%AF%86%E7%A0%81%E8%83%BD%E5%8A%9B%E5%BB%BA%E8%AE%BE-6.%E6%A0%A1%E9%AA%8C%E7%94%A8%E6%88%B7%E7%9A%84%E8%BA%AB%E4%BB%BD%E4%BF%A1%E6%81%AF
 * @param {Object} params 请求参数
 * @return {Promise}
 */


function checkidentity(params) {
  return ajaxData({
    url: API_BASE + "/activation/verification/identity/check",
    method: 'POST',
    contentType: 'application/json',
    data: params
  });
}
/**
 * 提交国政通校验
 * doc: https://doc.qima-inc.com/pages/viewpage.action?pageId=176850664#id-%E3%80%90%E6%8E%A5%E5%8F%A3%E6%96%87%E6%A1%A3%E3%80%91%E4%B8%AA%E4%BA%BA%E4%BC%9A%E5%91%98%E5%BC%80%E6%88%B7%E5%8F%8A%E6%94%AF%E4%BB%98%E5%AF%86%E7%A0%81%E8%83%BD%E5%8A%9B%E5%BB%BA%E8%AE%BE-2.%E5%9B%BD%E6%94%BF%E9%80%9A
 * @param {Object} params 请求参数
 * @return {Promise}
 */


function submitIdentity(params) {
  return ajaxData({
    url: API_BASE + "/activation/verification/identity/submit",
    method: 'POST',
    contentType: 'application/json',
    data: params
  });
}